@@ -10,8 +10,8 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!IMPL")
+(in-package "SB-IMPL")
 
-(defconstant sb!xc:internal-time-units-per-second 1000
+(defconstant sb-xc:internal-time-units-per-second 1000
   "The number of internal time units that fit into a second. See
 GET-INTERNAL-REAL-TIME and GET-INTERNAL-RUN-TIME.")
