@@ -10,18 +10,39 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!IMPL")
+(in-package "SB-IMPL")
 
 ;;;; utilities
 
+;;; like INDEX, but only up to half the maximum. Used by hash-table
+;;; code that does plenty to (aref v (* 2 i)) and (aref v (1+ (* 2 i))).
+(deftype index/2 () `(integer 0 (,(floor sb-xc:array-dimension-limit 2))))
+
+;;; T if and only if table has non-null weakness kind.
+(declaim (inline hash-table-weak-p))
+(defun hash-table-weak-p (ht) (logbitp 0 (hash-table-flags ht)))
+
+;;; Value of :synchronized constructor argument.
+(declaim (inline hash-table-synchronized-p))
+(defun hash-table-synchronized-p (ht) (logbitp 1 (hash-table-flags ht)))
+
+;;; Keep in sync with weak_ht_alivep_funs[] in gc-common
+(declaim (inline decode-hash-table-weakness))
+(defun decode-hash-table-weakness (x)
+  ;; The bits of 'weakness' are interpreted as follows:
+  ;;   bit 0 : live key forces value to be live
+  ;;   bit 1 : live value forces key to be live
+  ;;   both  : either forces the other to be live
+  ;; :KEY-AND-VALUE has two zero bits, as neither object livens the other
+  (aref #(:key-and-value :key :value :key-or-value) x))
+
+;;; Non-NIL if this is some kind of weak hash table. For details see
+;;; the docstring of MAKE-HASH-TABLE.
 (defun hash-table-weakness (ht)
   "Return the WEAKNESS of HASH-TABLE which is one of NIL, :KEY,
 :VALUE, :KEY-AND-VALUE, :KEY-OR-VALUE."
-  (aref weak-hash-table-kinds (hash-table-%weakness ht)))
-
-(declaim (inline hash-table-weak-p))
-(defun hash-table-weak-p (ht)
-  (not (zerop (hash-table-%weakness ht))))
+  (and (hash-table-weak-p ht)
+       (decode-hash-table-weakness (ash (hash-table-flags ht) -3))))
 
 ;;; Code for detecting concurrent accesses to the same table from
 ;;; multiple threads. Only compiled in when the :SB-HASH-TABLE-DEBUG
@@ -34,9 +55,9 @@
 (defmacro with-concurrent-access-check (hash-table operation &body body)
   (declare (ignorable hash-table operation)
            (type (member :read :write) operation))
-  #!-sb-hash-table-debug
+  #-sb-hash-table-debug
   `(progn ,@body)
-  #!+sb-hash-table-debug
+  #+sb-hash-table-debug
   (let ((thread-slot-accessor (if (eq operation :read)
                                   'hash-table-reading-thread
                                   'hash-table-writing-thread)))
@@ -60,7 +81,7 @@
                                                     ,hash-table)))))
                         (error-fun))
                       (setf (,thread-slot-accessor ,hash-table)
-                            sb!thread::*current-thread*)
+                            sb-thread::*current-thread*)
                       (body-fun))
                  (unless (and ,@(when (eq operation :read)
                                   `((null (hash-table-writing-thread
@@ -71,22 +92,22 @@
                                            ,hash-table))
                                     (eq (hash-table-writing-thread
                                          ,hash-table)
-                                        sb!thread::*current-thread*))))
+                                        sb-thread::*current-thread*))))
                    (error-fun))
                  (when (eq (,thread-slot-accessor ,hash-table)
-                           sb!thread::*current-thread*)
+                           sb-thread::*current-thread*)
                    ;; this is not 100% correct here and may hide
                    ;; concurrent access in rare circumstances.
                    (setf (,thread-slot-accessor ,hash-table) nil)))
                (body-fun)))))))
 
-#!-sb-fluid (declaim (inline eq-hash))
+#-sb-fluid (declaim (inline eq-hash))
 (defun eq-hash (key)
   (declare (values hash (member t nil)))
   (values (pointer-hash key)
           (oddp (get-lisp-obj-address key))))
 
-#!-sb-fluid (declaim (inline equal-hash))
+#-sb-fluid (declaim (inline equal-hash))
 (defun equal-hash (key)
   (declare (values hash (member t nil)))
   (typecase key
@@ -100,11 +121,15 @@
     (t
      (eq-hash key))))
 
-#!-sb-fluid (declaim (inline eql-hash))
+#-sb-fluid (declaim (inline eql-hash))
 (defun eql-hash (key)
   (declare (values hash (member t nil)))
-  (if (numberp key)
-      (equal-hash key)
+  (if (%other-pointer-subtype-p
+       key
+       '#.(list sb-vm:bignum-widetag sb-vm:ratio-widetag sb-vm:double-float-widetag
+                sb-vm:single-float-widetag
+                sb-vm:complex-widetag sb-vm:complex-single-float-widetag sb-vm:complex-double-float-widetag))
+      (values (sxhash key) nil)
       (eq-hash key)))
 
 (defun equalp-hash (key)
@@ -135,8 +160,6 @@
 
 ;;;; user-defined hash table tests
 
-(defglobal *user-hash-table-tests* nil)
-
 (defun register-hash-table-test (name hash-fun)
   (declare (symbol name) (function hash-fun))
   (unless (fboundp name)
@@ -224,12 +247,28 @@ Examples:
 ;;;; construction and simple accessors
 
 (defconstant +min-hash-table-size+ 16)
-(defconstant +min-hash-table-rehash-threshold+ (float 1/16 1.0))
+(defconstant +min-hash-table-rehash-threshold+ (float 1/16 $1.0))
+
+;; The GC will set this to 1 if it moves an EQ-based key. This used
+;; to be signaled by a bit in the header of the kv vector, but that
+;; implementation caused some concurrency issues when we stopped
+;; inhibiting GC during hash-table lookup.
+;;
+;; This indicator properly belongs to the k/v vector for at least 2 reasons:
+;; - if the vector is on an already-written page but the table is not,
+;;   it avoids a write fault when setting to true. This a boon to gencgc
+;; - if there were lock-free tables - which presumably operate by atomically
+;;   changing out the vector for a new one - whether the vector is bucketized
+;;   correctly after GC is an aspect of the vector, not the table
+;;
+;; We could do it with a single bit by implementing vops for atomic
+;; read/modify/write on the header. In C there's sync_or_and_fetch, etc.
+(defmacro kv-vector-needs-rehash (vector) `(svref ,vector 1))
 
 (defun make-hash-table (&key
                         (test 'eql)
                         (size +min-hash-table-size+)
-                        (rehash-size 1.5)
+                        (rehash-size $1.5)
                         (rehash-threshold 1)
                         (hash-function nil)
                         (weakness nil)
@@ -346,15 +385,15 @@ Examples:
                            ;; SIZE is just a hint, so if the user asks
                            ;; for a SIZE which'd be too big for us to
                            ;; easily implement, we bump it down.
-                           (floor array-dimension-limit 1024))))
+                           (floor sb-xc:array-dimension-limit 1024))))
            (rehash-size (if (integerp rehash-size)
                             rehash-size
-                            (float rehash-size 1.0)))
+                            (float rehash-size $1.0))) ; always single-float
            ;; FIXME: Original REHASH-THRESHOLD default should be 1.0,
            ;; not 1, to make it easier for the compiler to avoid
            ;; boxing.
            (rehash-threshold (max +min-hash-table-rehash-threshold+
-                                  (float rehash-threshold 1.0)))
+                                  (float rehash-threshold $1.0))) ; always single-float
            (size+1 (1+ size))       ; The first element is not usable.
            ;; KLUDGE: The most natural way of expressing the below is
            ;; (round (/ (float size+1) rehash-threshold)), and indeed
@@ -370,18 +409,24 @@ Examples:
            (scaled-size (truncate (/ (float size+1) rehash-threshold)))
            (length (power-of-two-ceiling (max scaled-size
                                               (1+ +min-hash-table-size+))))
-           (index-vector (make-array length
-                                     :element-type
-                                     '(unsigned-byte #.sb!vm:n-word-bits)
+           ;; FIXME: this is completely insane for 64-bit.
+           ;; We can not possibly support hash-tables that need
+           ;; such large indices. It doesn't work.
+           ;; Reducing this to (unsigned-byte 32) would save memory.
+           (index-vector (make-array length :element-type 'word
                                      :initial-element 0))
            ;; Needs to be the half the length of the KV vector to link
            ;; KV entries - mapped to indeces at 2i and 2i+1 -
            ;; together.
-           (next-vector (make-array size+1
-                                    :element-type
-                                    '(unsigned-byte #.sb!vm:n-word-bits)))
+           (next-vector (make-array size+1 :element-type 'word))
            (kv-vector (make-array (* 2 size+1)
                                   :initial-element +empty-ht-slot+))
+           (weakness (if weakness
+                         (or (loop for i below 4
+                                   when (eq (decode-hash-table-weakness i) weakness)
+                                   do (return (logior (ash i 3) 1)))
+                             (bug "Unreachable"))
+                         0))
            (table (%make-hash-table
                    test
                    test-fun
@@ -390,16 +435,15 @@ Examples:
                    rehash-threshold
                    size
                    kv-vector
-                   (position weakness weak-hash-table-kinds :test #'eq)
                    index-vector
                    next-vector
                    (unless (eq test 'eq)
-                     (make-array size+1
-                                 :element-type '(unsigned-byte
-                                                 #.sb!vm:n-word-bits)
+                     ;; See FIXME at INDEX-VECTOR. Same concern.
+                     (make-array size+1 :element-type 'word
                                  :initial-element +magic-hash-vector-value+))
-                   synchronized)))
+                   (logior (if synchronized 2 0) weakness))))
       (declare (type index size+1 scaled-size length))
+      (setf (kv-vector-needs-rehash kv-vector) 0)
       ;; Set up the free list, all free. These lists are 0 terminated.
       (do ((i 1 (1+ i)))
           ((>= i size))
@@ -415,13 +459,13 @@ Examples:
            (values index))
   (hash-table-number-entries hash-table))
 
-(setf (fdocumentation 'hash-table-rehash-size 'function)
+(setf (documentation 'hash-table-rehash-size 'function)
       "Return the rehash-size HASH-TABLE was created with.")
 
-(setf (fdocumentation 'hash-table-rehash-threshold 'function)
+(setf (documentation 'hash-table-rehash-threshold 'function)
       "Return the rehash-threshold HASH-TABLE was created with.")
 
-(setf (fdocumentation 'hash-table-synchronized-p 'function)
+(setf (documentation 'hash-table-synchronized-p 'function)
       "Returns T if HASH-TABLE is synchronized.")
 
 (defun hash-table-size (hash-table)
@@ -430,7 +474,7 @@ Examples:
    having to be grown."
   (hash-table-rehash-trigger hash-table))
 
-(setf (fdocumentation 'hash-table-test 'function)
+(setf (documentation 'hash-table-test 'function)
       "Return the test HASH-TABLE was created with.")
 
 ;;; Called when we detect circular chains in a hash-table.
@@ -444,45 +488,60 @@ multiple threads accessing the same hash-table without locking."
 
 ;;; Make new vectors for the table, extending the table based on the
 ;;; rehash-size.
-(defun rehash (table)
-  (declare (type hash-table table))
+(defun hash-table-new-vectors (table)
+  ;; Can at least some vectors be copied before entering WITHOUT-GCING
+  ;; for REHASH?
+  ;; So that they don't have to be alive at the same time and be collected.
+  (let* ((old-next-vector (hash-table-next-vector table))
+         (old-hash-vector (hash-table-hash-vector table))
+         (old-size (length old-next-vector))
+         (new-size
+           (power-of-two-ceiling
+            (let ((rehash-size (hash-table-rehash-size table)))
+              (etypecase rehash-size
+                (fixnum
+                 (+ rehash-size old-size))
+                (float
+                 (the index (truncate (* rehash-size old-size))))))))
+         (new-kv-vector (make-array (* 2 new-size)
+                                    :initial-element +empty-ht-slot+))
+         (new-next-vector
+           (make-array new-size :element-type 'word :initial-element 0))
+         (new-hash-vector
+           (when old-hash-vector
+             (make-array new-size
+                         :element-type 'word
+                         :initial-element +magic-hash-vector-value+)))
+         (new-index-vector (make-array new-size :element-type 'word :initial-element 0)))
+    (values new-size
+            new-kv-vector new-next-vector new-hash-vector new-index-vector)))
+
+(defun rehash (table new-size
+               new-kv-vector new-next-vector new-hash-vector
+               new-index-vector)
+  (declare (type hash-table table)
+           (type simple-vector new-kv-vector)
+           (type (simple-array word (*)) new-next-vector new-index-vector)
+           (type (or null (simple-array word (*))) new-hash-vector)
+           (type index new-size))
   (aver *gc-inhibit*)
   (let* ((old-kv-vector (hash-table-table table))
          (old-next-vector (hash-table-next-vector table))
          (old-hash-vector (hash-table-hash-vector table))
-         (old-size (length old-next-vector))
-         (new-size
-          (power-of-two-ceiling
-           (let ((rehash-size (hash-table-rehash-size table)))
-             (etypecase rehash-size
-               (fixnum
-                (+ rehash-size old-size))
-               (float
-                (the index (truncate (* rehash-size old-size))))))))
-         (new-kv-vector (make-array (* 2 new-size)
-                                    :initial-element +empty-ht-slot+))
-         (new-next-vector
-          (make-array new-size
-                      :element-type '(unsigned-byte #.sb!vm:n-word-bits)
-                      :initial-element 0))
-         (new-hash-vector
-          (when old-hash-vector
-            (make-array new-size
-                        :element-type '(unsigned-byte #.sb!vm:n-word-bits)
-                        :initial-element +magic-hash-vector-value+)))
-         (new-length new-size)
-         (new-index-vector
-          (make-array new-length
-                      :element-type '(unsigned-byte #.sb!vm:n-word-bits)
-                      :initial-element 0)))
-    (declare (type index new-size new-length old-size))
+         (old-size (length old-next-vector)))
 
     ;; Disable GC tricks on the OLD-KV-VECTOR.
-    (set-header-data old-kv-vector sb!vm:vector-normal-subtype)
+    (set-header-data old-kv-vector sb-vm:vector-normal-subtype)
+
+    ;; GC must never observe a value other than 0 or 1 in the 1st element
+    ;; of a vector marked as valid-hashing. The vector is initially filled
+    ;; with the unbound-marker, so rectify that. GC is inhibited (asserted
+    ;; on entry), so the store order here isn't terribly important.
+    (setf (kv-vector-needs-rehash new-kv-vector) 0)
 
     ;; Non-empty weak hash tables always need GC support.
     (when (and (hash-table-weak-p table) (plusp (hash-table-count table)))
-      (set-header-data new-kv-vector sb!vm:vector-valid-hashing-subtype))
+      (set-header-data new-kv-vector sb-vm:vector-valid-hashing-subtype))
 
     ;; FIXME: here and in several other places in the hash table code,
     ;; loops like this one are used when FILL or REPLACE would be
@@ -518,7 +577,7 @@ multiple threads accessing the same hash-table without locking."
                             +magic-hash-vector-value+)))
                ;; Can use the existing hash value (not EQ based)
                (let* ((hashing (aref new-hash-vector i))
-                      (index (index-for-hashing hashing new-length))
+                      (index (index-for-hashing hashing new-size))
                       (next (aref new-index-vector index)))
                  (declare (type index index)
                           (type hash hashing))
@@ -526,12 +585,12 @@ multiple threads accessing the same hash-table without locking."
                  (setf (aref new-next-vector i) next)
                  (setf (aref new-index-vector index) i)))
               (t
-               ;; EQ base hash.
+               ;; EQ-based hash.
                ;; Enable GC tricks.
                (set-header-data new-kv-vector
-                                sb!vm:vector-valid-hashing-subtype)
+                                sb-vm:vector-valid-hashing-subtype)
                (let* ((hashing (pointer-hash key))
-                      (index (index-for-hashing hashing new-length))
+                      (index (index-for-hashing hashing new-size))
                       (next (aref new-index-vector index)))
                  (declare (type index index)
                           (type hash hashing))
@@ -544,10 +603,9 @@ multiple threads accessing the same hash-table without locking."
     (setf (hash-table-hash-vector table) new-hash-vector)
     ;; Fill the old kv-vector with 0 to help the conservative GC. Even
     ;; if nothing else were zeroed, it's important to clear the
-    ;; special first cells in old-kv-vector.
+    ;; special first cell in old-kv-vector.
     (fill old-kv-vector 0)
-    (setf (hash-table-rehash-trigger table) new-size)
-    (setf (hash-table-needs-rehash-p table) nil))
+    (setf (hash-table-rehash-trigger table) new-size))
   (values))
 
 ;;; Use the same size as before, re-using the vectors.
@@ -566,7 +624,7 @@ multiple threads accessing the same hash-table without locking."
     (unless (and (hash-table-weak-p table) (plusp (hash-table-count table)))
       ;; Disable GC tricks, they will be re-enabled during the re-hash
       ;; if necessary.
-      (set-header-data kv-vector sb!vm:vector-normal-subtype))
+      (set-header-data kv-vector sb-vm:vector-normal-subtype))
 
     ;; Rehash all the entries.
     (setf (hash-table-next-free-kv table) 0)
@@ -594,9 +652,9 @@ multiple threads accessing the same hash-table without locking."
                  (setf (aref next-vector i) next)
                  (setf (aref index-vector index) i)))
               (t
-               ;; EQ base hash.
+               ;; EQ-based hash.
                ;; Enable GC tricks.
-               (set-header-data kv-vector sb!vm:vector-valid-hashing-subtype)
+               (set-header-data kv-vector sb-vm:vector-valid-hashing-subtype)
                (let* ((hashing (pointer-hash key))
                       (index (index-for-hashing hashing length))
                       (next (aref index-vector index)))
@@ -604,10 +662,10 @@ multiple threads accessing the same hash-table without locking."
                           (type hash hashing))
                  ;; Push this slot into the next chain.
                  (setf (aref next-vector i) next)
-                 (setf (aref index-vector index) i)))))))
+                 (setf (aref index-vector index) i))))))
   ;; Clear the rehash bit only at the very end, otherwise another thread
   ;; might see a partially rehashed table as a normal one.
-  (setf (hash-table-needs-rehash-p table) nil)
+    (setf (kv-vector-needs-rehash kv-vector) 0))
   (values))
 
 (declaim (inline maybe-rehash))
@@ -618,21 +676,30 @@ multiple threads accessing the same hash-table without locking."
            (and ensure-free-slot-p
                 (zerop (hash-table-next-free-kv hash-table))))
          (rehash-without-growing-p ()
-           (hash-table-needs-rehash-p hash-table)))
+           (not (eql 0 (kv-vector-needs-rehash (hash-table-table hash-table))))))
     (declare (inline rehash-p rehash-without-growing-p))
     (cond ((rehash-p)
            ;; Use recursive locks since for weak tables the lock has
-           ;; already been acquired. GC must be inhibited to prevent
-           ;; the GC from seeing a rehash in progress.
-           (sb!thread::with-recursive-system-lock
-               ((hash-table-lock hash-table) :without-gcing t)
+           ;; already been acquired.
+           (sb-thread::with-recursive-system-lock
+               ((hash-table-lock hash-table))
              ;; Repeat the condition inside the lock to ensure that if
              ;; two reader threads enter MAYBE-REHASH at the same time
              ;; only one rehash is performed.
              (when (rehash-p)
-               (rehash hash-table))))
+               ;; Cons new vectors outside of WITHOUT-GCING (except
+               ;; for weak hash-tables, GETHASH3 already uses
+               ;; WITHOUT-GCING in that case)
+               (multiple-value-bind (new-size new-kv-vector new-next-vector new-hash-vector new-index-vector)
+                   (hash-table-new-vectors hash-table)
+                 (without-gcing
+                   ;; Rehash inside WITHOUT-GCING to avoid movement
+                   ;; and the keep GC from seeing half-initilizaed
+                   ;; hash vectors.
+                   (rehash hash-table new-size new-kv-vector new-next-vector
+                           new-hash-vector new-index-vector))))))
           ((rehash-without-growing-p)
-           (sb!thread::with-recursive-system-lock
+           (sb-thread::with-recursive-system-lock
                ((hash-table-lock hash-table) :without-gcing t)
              (when (rehash-without-growing-p)
                (rehash-without-growing hash-table)))))))
@@ -653,7 +720,7 @@ multiple threads accessing the same hash-table without locking."
                 (locally (declare (inline ,@inline))
                   ,@body))))
        (if (hash-table-weak-p ,hash-table)
-           (sb!thread::with-recursive-system-lock
+           (sb-thread::with-recursive-system-lock
                ((hash-table-lock ,hash-table) :without-gcing t)
              (,body-fun))
            (with-pinned-objects ,pin
@@ -661,7 +728,7 @@ multiple threads accessing the same hash-table without locking."
                  ;; We use a "system" lock here because it is very
                  ;; slightly faster, as it doesn't re-enable
                  ;; interrupts.
-                 (sb!thread::with-recursive-system-lock
+                 (sb-thread::with-recursive-system-lock
                      ((hash-table-lock ,hash-table))
                    (,body-fun))
                  (,body-fun)))))))
@@ -681,7 +748,7 @@ if there is no such entry. Entries can be added using SETF."
            (values t (member t nil)))
   (tagbody
    start
-     (let ((start-epoch sb!kernel::*gc-epoch*))
+     (let ((start-epoch sb-kernel::*gc-epoch*))
        (macrolet ((result (value foundp)
                     ;; When the table has multiple concurrent readers,
                     ;; it's possible that there was a GC after this
@@ -692,7 +759,7 @@ if there is no such entry. Entries can be added using SETF."
                     ;; redo the lookup if the GC epoch counter has changed.
                     ;; -- JES,  2007-09-30
                     `(if (and (not ,foundp)
-                              (not (eq start-epoch sb!kernel::*gc-epoch*)))
+                              (not (eq start-epoch sb-kernel::*gc-epoch*)))
                          (go start)
                          (return-from %gethash3 (values ,value ,foundp))))
                   (overflow ()
@@ -783,11 +850,11 @@ if there is no such entry. Entries can be added using SETF."
            (test-fun (hash-table-test-fun hash-table)))
       (declare (type index index next))
       (when (hash-table-weak-p hash-table)
-        (set-header-data kv-vector sb!vm:vector-valid-hashing-subtype))
+        (set-header-data kv-vector sb-vm:vector-valid-hashing-subtype))
       (cond ((or eq-based (not hash-vector))
              (when eq-based
                (set-header-data kv-vector
-                                sb!vm:vector-valid-hashing-subtype))
+                                sb-vm:vector-valid-hashing-subtype))
              ;; Search next-vector chain for a matching key.
              (do ((next next (aref next-vector next))
                   (i 0 (1+ i)))
@@ -959,10 +1026,11 @@ table itself."
              (size (length next-vector))
              (index-vector (hash-table-index-vector hash-table)))
         ;; Disable GC tricks.
-        (set-header-data kv-vector sb!vm:vector-normal-subtype)
+        (set-header-data kv-vector sb-vm:vector-normal-subtype)
         ;; Mark all slots as empty by setting all keys and values to magic
         ;; tag.
         (aver (eq (aref kv-vector 0) hash-table))
+        (setf (kv-vector-needs-rehash kv-vector) 0)
         (fill kv-vector +empty-ht-slot+ :start 2)
         ;; Set up the free list, all free.
         (do ((i 1 (1+ i)))
