@@ -17,60 +17,64 @@
 
 (declaim (type (simple-array (unsigned-byte 32) (*)) **block-ranges**))
 (sb-ext:define-load-time-global **block-ranges**
-  #.(!coerce-to-specialized
-     (sb-cold:read-from-file "output/blocks.lisp-expr")
-     '(unsigned-byte 32)))
+  #.(sb-xc:coerce (sb-cold:read-from-file "output/blocks.lisp-expr")
+                  '(vector (unsigned-byte 32))))
 
 (macrolet ((unicode-property-init ()
-             (let ((proplist-dump
-                    (sb-cold:read-from-file "output/misc-properties.lisp-expr"))
-                   (confusable-sets
-                    (sb-cold:read-from-file "output/confusables.lisp-expr"))
+             (let ((confusable-sets
+                     (sb-cold:read-from-file "output/confusables.lisp-expr"))
                    (bidi-mirroring-list
-                    (sb-cold:read-from-file "output/bidi-mirrors.lisp-expr")))
+                     (sb-cold:read-from-file "output/bidi-mirrors.lisp-expr")))
                `(progn
-                  (sb-ext:define-load-time-global **proplist-properties**
-                    ',proplist-dump)
+                  (sb-ext:define-load-time-global **proplist-properties** nil)
                   (sb-ext:define-load-time-global **confusables**
-                    ',confusable-sets)
+                      ',confusable-sets)
                   (sb-ext:define-load-time-global **bidi-mirroring-glyphs**
-                    ',bidi-mirroring-list)
+                      ',bidi-mirroring-list)
                   (defun !unicode-properties-cold-init ()
-                    (let ((hash (make-hash-table)) (list ',proplist-dump))
-                      (do ((k (car list) (car list)) (v (cadr list) (cadr list)))
-                          ((not list) hash)
-                        (setf (gethash k hash) v)
-                        (setf list (cddr list)))
-                      (setf **proplist-properties** hash))
-                    (let ((hash (make-hash-table :test #'equal)))
-                      (loop for set in ',confusable-sets
-                         for items = (mapcar #'(lambda (item)
-                                                 (map 'simple-string
-                                                      #'code-char item))
-                                             #!+sb-unicode set
-                                             #!-sb-unicode
-                                             (remove-if-not
-                                              #'(lambda (item)
-                                                  (every
-                                                   #'(lambda (x)
-                                                       (< x sb-xc:char-code-limit))
-                                                   item)) set))
-                         do (dolist (i items)
-                              (setf (gethash (logically-readonlyize (possibly-base-stringize i))
-                                             hash)
-                                    (logically-readonlyize
-                                     (possibly-base-stringize (first items))))))
+                    ;;
+                    (let ((hash (make-hash-table :test 'eq))
+                          (list ',(sb-cold:read-from-file
+                                   "output/misc-properties.lisp-expr")))
+                      (setq **proplist-properties** hash)
+                      (loop for (symbol ranges) on list by #'cddr
+                            do (setf (gethash symbol hash)
+                                     (coerce ranges '(vector (unsigned-byte 32))))))
+                    ;;
+                    (let* ((data ',confusable-sets)
+                           (hash (make-hash-table :test #'eq
+                                                  #+sb-unicode :size #+sb-unicode (length data))))
+                      (loop for (source . target) in data
+                            when (and #-sb-unicode
+                                      (< source sb-xc:char-code-limit))
+                            do (flet ((minimize (x)
+                                        (case (length x)
+                                          (1
+                                           (elt x 0))
+                                          (2
+                                           (pack-3-codepoints (elt x 0) (elt x 1)))
+                                          (3
+                                           (pack-3-codepoints (elt x 0) (elt x 1) (elt x 2)))
+                                          (t
+                                           (logically-readonlyize
+                                            (possibly-base-stringize
+                                             (map 'string #'code-char x)))))))
+
+                                 (setf (gethash (code-char source) hash)
+                                       (minimize target))))
                       (setf **confusables** hash))
-                    (let ((hash (make-hash-table)) (list ',bidi-mirroring-list))
+                    ;;
+                    (let* ((list ',bidi-mirroring-list)
+                           (hash (make-hash-table :test #'eq :size (length list))))
                       (loop for (k v) in list do
-                           (setf (gethash k hash) v))
+                            (setf (gethash k hash) v))
                       (setf **bidi-mirroring-glyphs** hash)))))))
   (unicode-property-init))
 
 ;;; Unicode property access
 (defun ordered-ranges-member (item vector)
-  (declare (type simple-vector vector)
-           (type fixnum item)
+  (declare (type (simple-array (unsigned-byte 32) 1) vector)
+           (type char-code item)
            (optimize speed))
   (labels ((recurse (start end)
              (declare (type index start end)
@@ -78,8 +82,8 @@
              (when (< start end)
                (let* ((i (+ start (truncate (the index (- end start)) 2)))
                       (index (* 2 i))
-                      (elt1 (svref vector index))
-                      (elt2 (svref vector (1+ index))))
+                      (elt1 (aref vector index))
+                      (elt2 (aref vector (1+ index))))
                  (declare (type index i)
                           (fixnum elt1 elt2))
                  (cond ((< item elt1)
@@ -440,6 +444,10 @@ are excluded."
 disappears when accents are placed on top of it. and NIL otherwise"
   (proplist-p character :soft-dotted))
 
+(eval-when (:compile-toplevel)
+  (sb-xc:defmacro coerce-to-ordered-ranges (array)
+    (sb-xc:coerce array '(vector (unsigned-byte 32)))))
+
 (defun default-ignorable-p (character)
   "Returns T if CHARACTER is a Default_Ignorable_Code_Point"
   (and
@@ -450,8 +458,9 @@ disappears when accents are placed on top of it. and NIL otherwise"
     (or (whitespace-p character)
         (ordered-ranges-member
          (char-code character)
-         #(#x0600 #x0604 #x06DD #x06DD #x070F #x070F #xFFF9 #xFFFB
-           #x110BD #x110BD))))))
+         (coerce-to-ordered-ranges
+          #(#x0600 #x0604 #x06DD #x06DD #x070F #x070F #xFFF9 #xFFFB
+            #x110BD #x110BD)))))))
 
 
 ;;; Implements UAX#15: Normalization Forms
@@ -675,16 +684,16 @@ Acceptable values for form are :NFD, :NFC, :NFKD, and :NFKC.
 If FILTER is a function it is called on each decomposed character and
 only characters for which it returns T are collected."
   (declare (type (member :nfd :nfkd :nfc :nfkc) form))
-  #!-sb-unicode
+  #-sb-unicode
   (declare (ignore filter))
-  #!-sb-unicode
+  #-sb-unicode
   (etypecase string
     ((array nil (*)) string)
     (string
      (ecase form
        ((:nfc :nfkc) string)
        ((:nfd :nfkd) (error "Cannot normalize to ~A form in #-SB-UNICODE builds" form)))))
-  #!+sb-unicode
+  #+sb-unicode
   (etypecase string
     (base-string string)
     ((array character (*))
@@ -719,14 +728,24 @@ only characters for which it returns T are collected."
 
 (defun char-uppercase (char)
   (if (has-case-p char)
-      (let ((cp (car (char-case-info char))))
-        (if (atom cp) (list (code-char cp)) (mapcar #'code-char cp)))
+      (let ((cp (char-case-info char)))
+        (if (consp cp)
+            (let ((cp (car cp)))
+              (if (atom cp)
+                  (list (code-char cp))
+                  (mapcar #'code-char cp)))
+            (list (code-char (ldb (byte 21 21) cp)))))
       (list char)))
 
 (defun char-lowercase (char)
   (if (has-case-p char)
-      (let ((cp (cdr (char-case-info char))))
-        (if (atom cp) (list (code-char cp)) (mapcar #'code-char cp)))
+      (let ((cp (char-case-info char)))
+        (if (consp cp)
+            (let ((cp (cdr cp)))
+              (if (atom cp)
+                  (list (code-char cp))
+                  (mapcar #'code-char cp)))
+            (list (code-char (ldb (byte 21 0) cp)))))
       (list char)))
 
 (defun char-titlecase (char)
@@ -762,9 +781,9 @@ only characters for which it returns T are collected."
 (declaim (type function sb-unix::posix-getenv))
 (defun get-user-locale ()
   (let ((raw-locale
-         #!+(or win32 unix) (or (sb-unix::posix-getenv "LC_ALL")
+         #+(or win32 unix) (or (sb-unix::posix-getenv "LC_ALL")
                                 (sb-unix::posix-getenv "LANG"))
-         #!-(or win32 unix) nil))
+         #-(or win32 unix) nil))
     (when raw-locale
       (let ((lang-code (string-upcase
                         (subseq raw-locale 0 (position #\_ raw-locale)))))
@@ -782,8 +801,8 @@ Win32 only)."
   (when (eq locale t) (setf locale (get-user-locale)))
   (string-somethingcase
    #'char-uppercase string
-   #!-sb-unicode (constantly nil)
-   #!+sb-unicode ;; code-char with a constant > 255 breaks the build
+   #-sb-unicode (constantly nil)
+   #+sb-unicode ;; code-char with a constant > 255 breaks the build
    #'(lambda (char index len)
        (declare (ignore len))
        (cond
@@ -808,8 +827,8 @@ The result is not guaranteed to have the same length as the input.
   (when (eq locale t) (setf locale (get-user-locale)))
   (string-somethingcase
    #'char-lowercase string
-   #!-sb-unicode (constantly nil)
-   #!+sb-unicode
+   #-sb-unicode (constantly nil)
+   #+sb-unicode
    #'(lambda (char index len)
        (cond
          ((and (char= char (code-char #x03A3))
@@ -882,11 +901,11 @@ be longer than the input.
       for initial = (char word first-cased)
       for rest = (subseq word (1+ first-cased))
       do (let ((up (char-titlecase initial)) (down (lowercase rest)))
-           #!+sb-unicode
+           #+sb-unicode
            (when (and (or (eql locale :tr) (eql locale :az))
                       (eql initial #\i))
              (setf up (list (code-char #x0130))))
-           #!+sb-unicode
+           #+sb-unicode
            (when (and (eql locale :lt)
                       (soft-dotted-p initial)
                       (eql (char down
@@ -1000,11 +1019,13 @@ grapheme breaking rules specified in UAX #29, returning a list of strings."
   (when (listp char) (setf char (car char)))
   (let ((cp (when char (char-code char)))
         (gc (when char (general-category char)))
-        (newlines #(#xB #xC #x0085 #x0085 #x2028 #x2029))
+        (newlines
+         (coerce-to-ordered-ranges #(#xB #xC #x0085 #x0085 #x2028 #x2029)))
         (also-katakana
-         #(#x3031 #x3035 #x309B #x309C
-           #x30A0 #x30A0 #x30FC #x30FC
-           #xFF70 #xFF70))
+         (coerce-to-ordered-ranges
+          #(#x3031 #x3035 #x309B #x309C
+            #x30A0 #x30A0 #x30FC #x30FC
+            #xFF70 #xFF70)))
         (midnumlet #(#x002E #x2018 #x2019 #x2024 #xFE52 #xFF07 #xFF0E))
         (midletter
          #(#x003A #x00B7 #x002D7 #x0387 #x05F4 #x2027 #xFE13 #xFE55 #xFF1A))
@@ -1437,12 +1458,13 @@ it defaults to 80 characters"
   #.(sb-cold:read-from-file "output/other-collation-info.lisp-expr"))
 
 (defun unpack-collation-key (key)
-  (declare (type (simple-array (unsigned-byte 32) (*)) key))
-  (loop for value across key
-        collect
-        (list (ldb (byte 16 16) value)
-              (ldb (byte 11 5) value)
-              (ldb (byte 5 0) value))))
+  (flet ((unpack (value)
+           (list (ldb (byte 16 16) value)
+                 (ldb (byte 11 5) value)
+                 (ldb (byte 5 0) value))))
+    (declare (inline unpack))
+    (loop for i by 32 below (max (integer-length key) 1)
+          collect (unpack (ldb (byte 32 i) key)))))
 
 (declaim (inline variable-p))
 (defun variable-p (x)
@@ -1608,25 +1630,22 @@ with variable-weight characters, as described in UTS #10"
 ;;; Confusable detection
 
 (defun canonically-deconfuse (string)
-  (let (ret (i 0) new-i (len (length string))
-            best-node)
-    (loop while (< i len) do
-         (loop for offset from 1 to 5
-            while (<= (+ i offset) len)
-            do
-              (let ((node (gethash (subseq string i (+ i offset))
-                                   **confusables**)))
-                (when node (setf best-node node new-i (+ i offset)))))
-         (cond
-           (best-node (push best-node ret) (setf i new-i))
-           (t (push (subseq string i (1+ i)) ret) (incf i)))
-         (setf best-node nil new-i nil))
-    (apply #'concatenate 'string (nreverse ret))))
+  (let (result)
+    (loop for char across string
+          for deconfused = (gethash char **confusables**)
+          do (cond ((not deconfused)
+                    (push (string char) result))
+                   ((integerp deconfused)
+                    (push (sb-impl::unpack-3-codepoints deconfused)
+                          result))
+                   (t
+                    (push deconfused result))))
+    (apply #'concatenate 'string (nreverse result))))
 
 (defun confusable-p (string1 string2 &key (start1 0) end1 (start2 0) end2)
   "Determines whether STRING1 and STRING2 could be visually confusable
 according to the IDNA confusableSummary.txt table"
-    (let* ((form #!+sb-unicode :nfd #!-sb-unicode :nfc)
+    (let* ((form #+sb-unicode :nfd #-sb-unicode :nfc)
            (str1 (normalize-string (subseq string1 start1 end1) form))
            (str2 (normalize-string (subseq string2 start2 end2) form))
            (skeleton1 (normalize-string (canonically-deconfuse str1) form))
