@@ -21,53 +21,40 @@
 
 (sb-ext:unlock-package "CL")
 (rename-package "COMMON-LISP" "COMMON-LISP"
-                (cons "SB!XC" (package-nicknames "CL")))
+                (cons "SB-XC" (package-nicknames "CL")))
+;; Unlock all other SB- packages
+(dolist (package (list-all-packages))
+  (let ((name (package-name package)))
+    (when (sb-int:system-package-p name)
+      (sb-ext:unlock-package package))))
+
+;;; Define this first to avoid a style-warning from 'shebang'
+(defun read-target-float (stream char)
+  (declare (ignore stream char))
+  (values)) ; ignore the $ as if it weren't there
+(compile 'read-target-float)
 ;;; We need the #! readtable modifications.
 (load (merge-pathnames "shebang.lisp" *load-truename*))
+;;; ... applied to the default readtable
+(set-dispatch-macro-character #\# #\+ #'read-targ-feature-expr)
+(set-dispatch-macro-character #\# #\- #'read-targ-feature-expr)
+(set-macro-character #\$ #'read-target-float t)
 
 ;;; Just in case we want to play with the initial value of
 ;;; backend-subfeatures
 (setf sb-cold:*shebang-backend-subfeatures* sb-c:*backend-subfeatures*)
 
-(handler-bind ((sb-ext:package-locked-error #'continue))
-  ;; Any other name SB!FOO refers to the package now called SB-FOO.
-  (dolist (package (list-all-packages))
-    (let ((name (package-name package))
-          (nicknames (package-nicknames package))
-          (warm-name-prefix "SB-")
-          (cold-name-prefix "SB!"))
-      (when (and (> (length name) (length warm-name-prefix))
-                 (string= name warm-name-prefix
-                          :end1 (length warm-name-prefix)))
-        (let* ((stem (subseq name (length cold-name-prefix)))
-               (cold-name (concatenate 'simple-string cold-name-prefix stem)))
-          (rename-package package name (cons cold-name nicknames)))
-        (sb-ext:unlock-package package)))))
-
-;; Reinstate the pre-cold-init variable-defining macros.
-(let ((*package* (find-package "SB-INT")))
-  (flet ((def (real-name)
-           (let ((alias (sb-int:symbolicate "!" real-name)))
-             (export alias)
-             (setf (macro-function alias) (macro-function real-name)))))
-    (def 'sb-ext:defglobal)
-    (def 'defparameter)
-    (def 'defvar)))
+;; Restore !DEFINE-LOAD-TIME-GLOBAL macro
+(export 'sb-int::!define-load-time-global 'sb-int)
+(setf (macro-function 'sb-int::!define-load-time-global)
+      (macro-function 'sb-ext:define-load-time-global))
 
 (export '(sb-int::!cold-init-forms
-          sb-int::!coerce-to-specialized
           sb-int::/show sb-int::/noshow sb-int::/show0 sb-int::/noshow0)
         'sb-int)
 
 (defmacro sb-int:!cold-init-forms (&rest forms) `(progn ,@forms))
 
-;; This macro is never defined for the target Lisp,
-;; only the cross-compilation host (see "src/code/specializable-array")
-;; but it is needed to read x86-64/insts.lisp and other things.
-(defmacro sb-int:!coerce-to-specialized (a type)
-  (declare (ignore type))
-  a)
-
 ;; If :sb-show is present, then these symbols are fboundp.
 ;; Otherwise define them as no-ops.
 (unless (fboundp 'sb-int:/show)
