@@ -9,7 +9,7 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!VM")
+(in-package "SB-VM")
 
 ;;;; Move functions:
 
@@ -413,7 +413,7 @@
                   (:variant :double  ,is-=)))))
   (frob < :mi </single-float </double-float nil)
   (frob > :gt >/single-float >/double-float nil)
-  (frob = :eq eql/single-float eql/double-float t))
+  (frob = :eq =/single-float =/double-float t))
 
 (define-vop (float-compare-zero)
   (:args (x))
@@ -442,9 +442,9 @@
                 (:args (x :scs (,sc)))
                 (:arg-types ,ptype (:constant, constant-type)))))
   (frob single-float-compare-zero single-reg single-float
-        (single-float -0f0 0f0))
+        (single-float $-0f0 $0f0))
   (frob double-float-compare-zero double-reg double-float
-        (double-float -0d0 0d0)))
+        (double-float $-0d0 $0d0)))
 
 (macrolet ((frob (translate cond sname dname is-=)
              `(progn
@@ -661,7 +661,7 @@
 
 ;;;; Float mode hackery:
 
-(sb!xc:deftype float-modes () '(unsigned-byte 32))
+(sb-xc:deftype float-modes () '(unsigned-byte 32))
 (defknown floating-point-modes () float-modes (flushable))
 (defknown ((setf floating-point-modes)) (float-modes)
   float-modes)
