@@ -10,7 +10,7 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!VM")
+(in-package "SB-VM")
 
 ;;; Make a fixnum out of NUM. (I.e. shift by two bits if it will fit.)
 (defun fixnumize (num)
@@ -19,12 +19,12 @@
       (error "~W is too big for a fixnum." num)))
 
 ;;; Determining whether a constant offset fits in an addressing mode.
-#!+(or x86 x86-64)
+#+(or x86 x86-64)
 (defun foldable-constant-offset-p (element-size lowtag data-offset offset)
   (if (< element-size n-byte-bits)
       nil
       (multiple-value-bind (min max)
-          (sb!impl::displacement-bounds lowtag element-size data-offset)
+          (displacement-bounds lowtag element-size data-offset)
         (<= min offset max))))
 
 
@@ -105,9 +105,9 @@
 ;;; Make a TN to hold the number-stack frame pointer.  This is allocated
 ;;; once per component, and is component-live.
 (defun make-nfp-tn ()
-  #!+c-stack-is-control-stack
+  #+c-stack-is-control-stack
   (make-restricted-tn *fixnum-primitive-type* ignore-me-sc-number)
-  #!-c-stack-is-control-stack
+  #-c-stack-is-control-stack
   (component-live-tn
    (make-wired-tn *fixnum-primitive-type* immediate-arg-scn nfp-offset)))
 
@@ -117,15 +117,15 @@
    (make-representation-tn *fixnum-primitive-type* any-reg-sc-number)
    env))
 
-#!-x86-64
+#-x86-64
 (defun make-stack-pointer-tn (&optional nargs)
   (declare (ignore nargs))
   (make-normal-tn *fixnum-primitive-type*))
 
 (defun make-number-stack-pointer-tn ()
-  #!+c-stack-is-control-stack
+  #+c-stack-is-control-stack
   (make-restricted-tn *fixnum-primitive-type* ignore-me-sc-number)
-  #!-c-stack-is-control-stack
+  #-c-stack-is-control-stack
   (make-normal-tn *fixnum-primitive-type*))
 
 ;;; Return a list of TNs that can be used to represent an unknown-values
@@ -133,9 +133,9 @@
 (defun make-unknown-values-locations (&optional unused-count)
   (declare (ignorable unused-count))
   (list (make-stack-pointer-tn)
-        (cond #!+x86-64 ;; needs support from receive-unknown-values
+        (cond #+x86-64 ;; needs support from receive-unknown-values
               (unused-count
-               (sb!c::make-unused-tn))
+               (sb-c::make-unused-tn))
               (t
                (make-normal-tn *fixnum-primitive-type*)))))
 
@@ -158,9 +158,21 @@
   "Cause a continuable error.  ERROR-CODE is the error to cause."
   (emit-error-break vop cerror-trap (error-number-or-lose error-code) values))
 
-#!+sb-safepoint
+#+sb-safepoint
 (define-vop (insert-safepoint)
   (:policy :fast-safe)
-  (:translate sb!kernel::gc-safepoint)
+  (:translate sb-kernel::gc-safepoint)
   (:generator 0
     (emit-safepoint)))
+
+(defun other-pointer-tn-ref-p (tn-ref)
+  (and (sc-is (tn-ref-tn tn-ref) descriptor-reg)
+       (tn-ref-type tn-ref)
+       (not (types-equal-or-intersect
+             (tn-ref-type tn-ref)
+             (specifier-type '(or fixnum
+                               #+64-bit single-float
+                               function
+                               list
+                               instance
+                               character))))))
