@@ -67,7 +67,7 @@
   ;; cross-compile time so we can just use a fixed offset within the
   ;; TLS block instead of mucking about with the extra memory access
   ;; (and temp register, for stores)?
-  #!+sb-thread
+  #+sb-thread
   (defmacro load-tl-symbol-value (reg symbol)
     `(progn
        (inst lwz ,reg null-tn
@@ -75,11 +75,11 @@
                 (ash symbol-tls-index-slot word-shift)
                 (- other-pointer-lowtag)))
        (inst lwzx ,reg thread-base-tn ,reg)))
-  #!-sb-thread
+  #-sb-thread
   (defmacro load-tl-symbol-value (reg symbol)
     `(load-symbol-value ,reg ,symbol))
 
-  #!+sb-thread
+  #+sb-thread
   (defmacro store-tl-symbol-value (reg symbol temp)
     `(progn
        (inst lwz ,temp null-tn
@@ -87,7 +87,7 @@
                 (ash symbol-tls-index-slot word-shift)
                 (- other-pointer-lowtag)))
        (inst stwx ,reg thread-base-tn ,temp)))
-  #!-sb-thread
+  #-sb-thread
   (defmacro store-tl-symbol-value (reg symbol temp)
     (declare (ignore temp))
     `(store-symbol-value ,reg ,symbol)))
@@ -119,7 +119,8 @@
 (defmacro lisp-return (return-pc lip &key (offset 0))
   "Return to RETURN-PC."
   `(progn
-     (inst addi ,lip ,return-pc (- (* (1+ ,offset) n-word-bytes) other-pointer-lowtag))
+     (inst addi ,lip ,return-pc
+           (+ (- other-pointer-lowtag) n-word-bytes (* ,offset 4)))
      (inst mtlr ,lip)
      (inst blr)))
 
@@ -191,9 +192,9 @@
   ;; then or in the lowtag.
   ;; Normal allocation to the heap.
   (declare (ignore stack-p node)
-           #!-gencgc
+           #-gencgc
            (ignore temp-tn flag-tn))
-    #!-gencgc
+    #-gencgc
     (let ((alloc-size (gensym)))
       `(let ((,alloc-size ,size))
          (if (logbitp (1- n-lowtag-bits) ,lowtag)
@@ -205,7 +206,7 @@
          (if (numberp ,alloc-size)
              (inst addi alloc-tn alloc-tn ,alloc-size)
              (inst add alloc-tn alloc-tn ,alloc-size))))
-    #!+gencgc
+    #+gencgc
     `(progn
        ;; Make temp-tn be the size
        (cond ((numberp ,size)
@@ -213,23 +214,18 @@
              (t
               (move ,temp-tn ,size)))
 
-       #!-sb-thread
-       (inst lr ,flag-tn (make-fixup "gc_alloc_region" :foreign))
-       #!-sb-thread
-       (inst ld ,result-tn ,flag-tn 0)
-       #!+sb-thread
+       #-sb-thread
+       ;; thread-base-tn will point directly to the C variable
+       (progn (inst lr thread-base-tn (make-fixup "gc_alloc_region" :foreign-dataref))
+              (inst ld thread-base-tn thread-base-tn 0) ; because sb-dynamic-core
+              (inst ld ,result-tn thread-base-tn 0))
+       #+sb-thread
        (inst ld ,result-tn thread-base-tn (* thread-alloc-region-slot
                                               n-word-bytes))
 
-       ;; we can optimize this to only use one fixup here, once we get
-       ;; it working
-       ;; (inst lr ,flag-tn (make-fixup "gc_alloc_region" :foreign 4))
-       ;; (inst lwz ,flag-tn ,flag-tn 0)
-       #!-sb-thread
-       (inst ld ,flag-tn ,flag-tn n-word-bytes)
-       #!+sb-thread
-       (inst ld ,flag-tn thread-base-tn (* (1+ thread-alloc-region-slot)
-                                            n-word-bytes))
+       (inst ld ,flag-tn thread-base-tn ; region->end_addr
+             #-sb-thread n-word-bytes
+             #+sb-thread(* (1+ thread-alloc-region-slot) n-word-bytes))
 
        (without-scheduling ()
          ;; CAUTION: The C code depends on the exact order of
@@ -246,20 +242,13 @@
          ;; the actual end of the region?  If so, we need a full alloc.
          ;; The C code depends on this exact form of instruction.  If
          ;; either changes, you have to change the other appropriately!
-         ;; FIXME: shouldn't this be "tw :lgt" ? otherwise we're saying
-         ;; that allocation fails if we exactly hit the end pointer
-         (inst tw :lge ,result-tn ,flag-tn)
+         (inst tw :lgt ,result-tn ,flag-tn)
 
          ;; The C code depends on this instruction sequence taking up
-         ;; #!-sb-thread three #!+sb-thread one machine instruction.
-         ;; The lr of a fixup counts as two instructions.
-         #!-sb-thread
-         (progn
-           (inst lr ,flag-tn (make-fixup "gc_alloc_region" :foreign))
-           (inst std ,result-tn ,flag-tn 0))
-         #!+sb-thread
-         (inst stw ,result-tn thread-base-tn (* thread-alloc-region-slot
-                                                n-word-bytes)))
+         ;; one machine instruction.
+         (inst std ,result-tn thread-base-tn
+               #-sb-thread 0
+               #+sb-thread (* thread-alloc-region-slot n-word-bytes)))
 
        ;; Should the allocation trap above have fired, the runtime
        ;; arranges for execution to resume here, just after where we
@@ -336,9 +325,9 @@
 ;;; trap if ALLOC-TN's negative (handling the deferred interrupt) and
 ;;; using FLAG-TN - minus the large constant - to correct ALLOC-TN.
 (defmacro pseudo-atomic ((flag-tn) &body forms)
-  #!+sb-safepoint-strictly
+  #+sb-safepoint-strictly
   `(progn ,flag-tn ,@forms (emit-safepoint))
-  #!-sb-safepoint-strictly
+  #-sb-safepoint-strictly
   `(progn
      (without-scheduling ()
        ;; Extra debugging stuff:
@@ -358,9 +347,9 @@
      (progn
        (inst andi. ,flag-tn alloc-tn lowtag-mask)
        (inst twi :ne ,flag-tn 0))
-     #!+sb-safepoint
+     #+sb-safepoint
      (emit-safepoint)))
 
-#!+sb-safepoint
+#+sb-safepoint
 (defun emit-safepoint ()
   (inst lwz zero-tn null-tn (- (+ gc-safepoint-trap-offset n-word-bytes other-pointer-lowtag))))
