@@ -11,18 +11,22 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!C")
+(in-package "SB-C")
 
 ;;;; CL:COMPILE
 
-;;; Handle the nontrivial case of CL:COMPILE.
-;;;
-;;; If ERRORP is true signals an error immediately -- otherwise returns
+;;; Handle the following:
+;;;  - CL:COMPILE when the argument is not already a compiled function.
+;;;  - %SIMPLE-EVAL in "pretend we don't have an interpreter" mode
+;;;    a/k/a "compile all the things"
+;;;  - SB-INTERPRETER::EVAL-IN-ENVIRONMENT when it can't just do that.
+
+;;; If ERORRP is true signals an error immediately -- otherwise returns
 ;;; a function that will signal the error.
-(defun actually-compile (name form *lexenv* source-info tlf errorp)
+(defun compile-in-lexenv (form *lexenv* name source-info tlf ephemeral errorp)
   (let ((source-paths (when source-info *source-paths*)))
     (with-compilation-values
-      (sb!xc:with-compilation-unit ()
+      (sb-xc:with-compilation-unit ()
         ;; FIXME: These bindings were copied from SUB-COMPILE-FILE with
         ;; few changes. Once things are stable, the shared bindings
         ;; probably be merged back together into some shared utility
@@ -81,10 +85,9 @@
                          ;; the error came from, not how the compiler got there.
                          (go :error))))
                  (return
-                   (with-world-lock ()
-                     (%compile form (make-core-object)
+                     (%compile form (make-core-object ephemeral)
                                :name name
-                               :path `(original-source-start 0 ,tlf))))))
+                               :path `(original-source-start 0 ,tlf)))))
            :error
              ;; Either signal the error right away, or return a function that
              ;; will signal the corresponding COMPILED-PROGRAM-ERROR. This is so
@@ -105,22 +108,6 @@
                               :message message
                               :source source)))))))))))
 
-(defun compile-in-lexenv (definition lexenv &optional name source-info tlf errorp)
-  (multiple-value-bind (sexpr lexenv)
-      (typecase definition
-        #!+sb-fasteval
-        (sb!interpreter:interpreted-function
-         (sb!interpreter:prepare-for-compile definition))
-        #!+sb-eval
-        (sb!eval:interpreted-function
-         (sb!eval:prepare-for-compile definition))
-        (t
-         (values definition lexenv)))
-    (multiple-value-bind (compiled-definition warnings-p failure-p)
-        (actually-compile name (the cons sexpr) lexenv source-info tlf errorp)
-      (aver (typep compiled-definition 'compiled-function))
-      (values compiled-definition warnings-p failure-p))))
-
 (defun compile (name &optional (definition (or (and (symbolp name)
                                                     (macro-function name))
                                                (fdefinition name))))
@@ -143,9 +130,16 @@ Tertiary value is true if any conditions of type ERROR, or WARNING that are
 not STYLE-WARNINGs occur during compilation, and NIL otherwise.
 "
   (multiple-value-bind (compiled-definition warnings-p failure-p)
+      ;; TODO: generic functions with any interpreted methods
+      ;; should compile the methods and reinstall them.
       (if (compiled-function-p definition)
           (values definition nil nil)
-          (compile-in-lexenv definition (make-null-lexenv) name))
+          (multiple-value-bind (sexpr lexenv)
+              (if (not (typep definition 'interpreted-function))
+                  (values (the cons definition) (make-null-lexenv))
+                  #+(or sb-eval sb-fasteval)
+                  (prepare-for-compile definition))
+            (compile-in-lexenv sexpr lexenv name nil nil nil nil)))
     (values (cond (name
                    (if (and (symbolp name) (macro-function name))
                        (setf (macro-function name) compiled-definition)
