@@ -44,19 +44,19 @@
       ((double-reg complex-double-reg)
        (aver (xmm-tn-p src))
        (inst movapd dst src))
-      #!+sb-simd-pack
+      #+sb-simd-pack
       ((int-sse-reg sse-reg)
        (aver (xmm-tn-p src))
        (inst movdqa dst src))
-      #!+sb-simd-pack
+      #+sb-simd-pack
       ((single-sse-reg double-sse-reg)
        (aver (xmm-tn-p src))
        (inst movaps dst src))
-      #!+sb-simd-pack-256
+      #+sb-simd-pack-256
       ((int-avx2-reg avx2-reg)
        (aver (xmm-tn-p src))
        (inst vmovdqa dst src))
-      #!+sb-simd-pack-256
+      #+sb-simd-pack-256
       ((single-avx2-reg double-avx2-reg)
        (aver (xmm-tn-p src))
        (inst vmovaps dst src))
@@ -114,10 +114,15 @@
   ;; explicit displacement of 0.  Using INDEX as base avoids the extra byte.
   (ea index thread-base-tn))
 
+;;; assert that alloc-region->free_pointer and ->end_addr can be accessed
+;;; using a single byte displacement from thread-base-tn
+(eval-when (:compile-toplevel)
+  (aver (<= (1+ thread-alloc-region-slot) 15)))
+
 (defun thread-slot-ea (slot-index)
   (ea (ash slot-index word-shift) thread-base-tn))
 
-#!+sb-thread
+#+sb-thread
 (progn
   ;; Return an EA for the TLS of SYMBOL, or die.
   (defun symbol-known-tls-cell (symbol)
@@ -133,7 +138,7 @@
   (defmacro store-tl-symbol-value (reg symbol)
     `(inst mov (symbol-known-tls-cell ',symbol) ,reg)))
 
-#!-sb-thread
+#-sb-thread
 (progn
   (defmacro load-tl-symbol-value (reg symbol)
     `(inst mov ,reg (static-symbol-value-ea ',symbol)))
@@ -187,24 +192,24 @@
 
 ;;; Unsafely clear pa flags so that the image can properly lose in a
 ;;; pa section.
-#!+sb-thread
+#+sb-thread
 (defmacro %clear-pseudo-atomic ()
   '(inst mov :qword (thread-slot-ea thread-pseudo-atomic-bits-slot) 0))
 
-#!+sb-safepoint
+#+sb-safepoint
 (defun emit-safepoint ()
   (inst test :byte rax-tn (ea (- nil-value n-word-bytes other-pointer-lowtag
                                  gc-safepoint-trap-offset))))
 
 (defmacro pseudo-atomic ((&key elide-if) &rest forms)
-  #!+sb-safepoint-strictly
+  #+sb-safepoint-strictly
   `(progn ,@forms (unless ,elide-if (emit-safepoint)))
-  #!-sb-safepoint-strictly
+  #-sb-safepoint-strictly
   (with-unique-names (label pa-bits-ea)
     `(let ((,label (gen-label))
            (,pa-bits-ea
-            #!+sb-thread (thread-slot-ea thread-pseudo-atomic-bits-slot)
-            #!-sb-thread (static-symbol-value-ea '*pseudo-atomic-bits*)))
+            #+sb-thread (thread-slot-ea thread-pseudo-atomic-bits-slot)
+            #-sb-thread (static-symbol-value-ea '*pseudo-atomic-bits*)))
        (unless ,elide-if
          (inst mov ,pa-bits-ea rbp-tn))
        ,@forms
@@ -215,7 +220,7 @@
          ;; using the process signal mask.
          (inst break pending-interrupt-trap)
          (emit-label ,label)
-         #!+sb-safepoint
+         #+sb-safepoint
          ;; In this case, when allocation thinks a GC should be done, it
          ;; does not mark PA as interrupted, but schedules a safepoint
          ;; trap instead.  Let's take the opportunity to trigger that
@@ -224,6 +229,16 @@
 
 ;;;; indexed references
 
+(sb-xc:deftype load/store-index (scale lowtag min-offset
+                                 &optional (max-offset min-offset))
+  `(integer ,(- (truncate (+ (ash 1 16)
+                             (* min-offset sb-vm:n-word-bytes)
+                             (- lowtag))
+                          scale))
+            ,(truncate (- (+ (1- (ash 1 16)) lowtag)
+                          (* max-offset sb-vm:n-word-bytes))
+                       scale)))
+
 (defmacro define-full-compare-and-swap
     (name type offset lowtag scs el-type &optional translate)
   `(progn
