@@ -39,7 +39,9 @@
 
 #include "validate.h"
 #include "gc-internal.h"
+#include "gc-private.h"
 #include "pseudo-atomic.h"
+#include "code.h"
 
 #include <errno.h>
 
@@ -47,6 +49,15 @@
 # include <zlib.h>
 #endif
 
+/* build_id must match between the C code and .core file because a core
+ * is only guaranteed to be compatible with the C runtime that created it.
+ * We can't easily detect whether the sources were patched after saving
+ * a core, but we can easily enforce a matching build_id.
+ * Note that fasls have a different way of ensuring compatibility with the
+ * core: the contents of version.lisp-expr are written into the fasl.
+ * Both checks avoid confusion for end-users, but the build_id test
+ * is more geared toward developers as it can change with each rebuild.
+ */
 unsigned char build_id[] =
 // The suffix added to build-id indicates which flavor of C compiler was used.
 // This enforces that when you put :MSAN in your Lisp features, you don't
@@ -74,12 +85,16 @@ open_binary(char *filename, int mode)
 
 #if defined(LISP_FEATURE_LINUX) && defined(LISP_FEATURE_IMMOBILE_CODE)
 #define ELFCORE 1
-extern __attribute__((weak)) lispobj
- __lisp_code_start, __lisp_code_end, __lisp_linkage_values;
-static inline boolean code_in_elf() { return &__lisp_code_start != 0; }
-#else
+#elif !defined(ELFCORE)
 #define ELFCORE 0
-static inline boolean code_in_elf() { return 0; }
+#endif
+
+#if !ELFCORE
+int lisp_code_in_elf() { return 0; }
+#else
+extern __attribute__((weak)) lispobj
+ lisp_code_start, lisp_jit_code, lisp_code_end, lisp_linkage_values;
+int lisp_code_in_elf() { return &lisp_code_start != 0; }
 #endif
 
 /* Search 'filename' for an embedded core.  An SBCL core has, at the
@@ -124,7 +139,7 @@ search_for_embedded_core(char *filename, struct memsize_options *memsize_options
             read(fd, &header, lispobj_size) != lispobj_size || header != CORE_MAGIC)
             core_start = -1; // reset to invalid
     }
-#if ELFCORE
+#if ELFCORE && !defined(LISP_FEATURE_DARWIN)
     // Specifying "--core" as an ELF file with a lisp.core section doesn't work.
     // (There are bunch of reasons) So only search for a core section if this
     // is an implicit search for a core embedded in an executable.
@@ -144,6 +159,7 @@ search_for_embedded_core(char *filename, struct memsize_options *memsize_options
             && optarray[0] == RUNTIME_OPTIONS_MAGIC) {
             memsize_options->dynamic_space_size = optarray[2];
             memsize_options->thread_control_stack_size = optarray[3];
+            memsize_options->thread_tls_bytes = optarray[4];
             memsize_options->present_in_core = 1;
         }
     }
@@ -369,11 +385,11 @@ static void __attribute__((unused))
 adjust_code_refs(struct heap_adjust* adj, struct code* code, lispobj original_vaddr)
 {
 #ifdef LISP_FEATURE_IMMOBILE_SPACE
-    // Dynamic space is a always relocated before immobile space,
+    // Dynamic space always gets relocated before immobile space does,
     // and dynamic space code does not use fixups (except on 32-bit x86).
     // So if we're here, it must be to relocate an immobile object.
     // If 'code->fixups' is a bignum, the pointer itself was already fixed up.
-    char* instructions = (char*)((lispobj*)code + code_header_words(code->header));
+    char* instructions = code_text_start(code);
     struct varint_unpacker unpacker;
 
     varint_unpacker_init(&unpacker, code->fixups);
@@ -386,6 +402,8 @@ adjust_code_refs(struct heap_adjust* adj, struct code* code, lispobj original_va
         void* fixup_where = instructions + loc;
         lispobj ptr = UNALIGNED_LOAD32(fixup_where);
         lispobj adjusted = ptr + calc_adjustment(adj, ptr);
+        if (!(adjusted <= UINT32_MAX))
+            lose("Absolute fixup @ %p exceeds 32 bits", fixup_where);
         if (adjusted != ptr)
             FIXUP32(UNALIGNED_STORE32(fixup_where, adjusted), fixup_where);
     }
@@ -397,8 +415,10 @@ adjust_code_refs(struct heap_adjust* adj, struct code* code, lispobj original_va
         loc += prev_loc;
         prev_loc = loc;
         void* fixup_where = instructions + loc;
-        lispobj rel32operand = UNALIGNED_LOAD32(fixup_where);
-        lispobj adjusted = rel32operand - displacement;
+        int32_t rel32operand = UNALIGNED_LOAD32(fixup_where);
+        sword_t adjusted = (sword_t)rel32operand - displacement;
+        if (!(adjusted >= INT32_MIN && adjusted <= INT32_MAX))
+            lose("Relative fixup @ %p exceeds 32 bits", fixup_where);
         FIXUP_rel(UNALIGNED_STORE32(fixup_where, adjusted), fixup_where);
     }
 #endif
@@ -463,7 +483,7 @@ static void relocate_space(uword_t start, lispobj* end, struct heap_adjust* adj)
             nwords = 2;
             continue;
         }
-        widetag = widetag_of(header_word);
+        widetag = header_widetag(header_word);
         nwords = sizetab[widetag](where);
         switch (widetag) {
         case FUNCALLABLE_INSTANCE_WIDETAG:
@@ -485,7 +505,7 @@ static void relocate_space(uword_t start, lispobj* end, struct heap_adjust* adj)
 #endif
             bitmap = LAYOUT(adjusted_layout)->bitmap;
             gc_assert(fixnump(bitmap)
-                      || widetag_of(*native_pointer(bitmap))==BIGNUM_WIDETAG);
+                      || widetag_of(native_pointer(bitmap))==BIGNUM_WIDETAG);
             // If the post-adjustment address of 'layout' is higher than 'where',
             // then the layout's pointer slots need adjusting.
             // This is true regardless of whether the core was mapped at a higher
@@ -526,10 +546,14 @@ static void relocate_space(uword_t start, lispobj* end, struct heap_adjust* adj)
 #endif
             continue;
         case CODE_HEADER_WIDETAG:
+            if (filler_obj_p(where)) {
+                if (where[2]) adjust_word_at(where+2, adj);
+                continue;
+            }
             // Fixup the constant pool. The word at where+1 is a fixnum.
-            adjust_pointers(where+2, code_header_words(header_word)-2, adj);
-            // Fixup all embedded simple-funs
             code = (struct code*)where;
+            adjust_pointers(where+2, code_header_words(code)-2, adj);
+            // Fixup all embedded simple-funs
             for_each_simple_fun(i, f, code, 1, {
                 fix_fun_header_layout((lispobj*)f, adj);
 #if FUN_SELF_FIXNUM_TAGGED
@@ -622,6 +646,9 @@ static void relocate_space(uword_t start, lispobj* end, struct heap_adjust* adj)
         case COMPLEX_DOUBLE_FLOAT_WIDETAG:
 #ifdef SIMD_PACK_WIDETAG
         case SIMD_PACK_WIDETAG:
+#endif
+#ifdef SIMD_PACK_256_WIDETAG
+        case SIMD_PACK_256_WIDETAG:
 #endif
             continue;
         default:
@@ -629,7 +656,7 @@ static void relocate_space(uword_t start, lispobj* end, struct heap_adjust* adj)
               && specialized_vector_widetag_p(widetag))
               continue;
           else
-              lose("Unrecognized heap object: @%p: %lx\n", where, header_word);
+              lose("Unrecognized heap object: @%p: %"OBJ_FMTX, where, header_word);
         }
         adjust_pointers(where+1, nwords-1, adj);
     }
@@ -665,12 +692,12 @@ static void relocate_heap(struct heap_adjust* adj)
     // Assembler routines move with varyobj space.
     // (They're in readonly space if no immobile space)
     struct code* code = get_asm_routine_code_component();
-    lispobj* jump_table = (lispobj*)code + code_header_words(code->header);
+    lispobj* jump_table = (lispobj*)code_text_start(code);
     for ( ; *jump_table ; ++jump_table )
         adjust_word_at(jump_table, adj);
     // Pointers within varyobj space to varyobj space do not need adjustment
     // so remove any delta before performing the relocation pass on this space.
-    if (code_in_elf())
+    if (lisp_code_in_elf())
         adj->range[2].delta = 0; // FIXME: isn't this this already the case?
     relocate_space(VARYOBJ_SPACE_START, varyobj_free_pointer, adj);
 #endif
@@ -691,6 +718,12 @@ set_adjustment(struct heap_adjust* adj,
 }
 #endif
 
+#if defined(LISP_FEATURE_ELF) && defined(LISP_FEATURE_IMMOBILE_SPACE)
+    extern int apply_pie_relocs(long,long,int);
+#else
+#   define apply_pie_relocs(dummy1,dummy2,dummy3) (0)
+#endif
+
 static void
 process_directory(int count, struct ndir_entry *entry,
                   int fd, os_vm_offset_t file_offset,
@@ -726,19 +759,21 @@ process_directory(int count, struct ndir_entry *entry,
     };
 
 #if ELFCORE
-    if (&__lisp_code_start) {
-        VARYOBJ_SPACE_START = (uword_t)&__lisp_code_start;
-        varyobj_free_pointer = &__lisp_code_end;
-        uword_t aligned_end = ALIGN_UP((uword_t)&__lisp_code_end, IMMOBILE_CARD_BYTES);
-        varyobj_space_size = aligned_end - VARYOBJ_SPACE_START;
+    if (&lisp_code_start) {
+        VARYOBJ_SPACE_START = (uword_t)&lisp_code_start;
+        varyobj_free_pointer = &lisp_jit_code;
+        varyobj_space_size = (uword_t)&lisp_code_end - VARYOBJ_SPACE_START;
         spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].len = varyobj_space_size;
-        gc_assert(varyobj_free_pointer >= (lispobj*)VARYOBJ_SPACE_START);
-#if !ENABLE_PAGE_PROTECTION
+        if (varyobj_free_pointer < (lispobj*)VARYOBJ_SPACE_START
+            || !PTR_IS_ALIGNED(&lisp_code_end, 4096))
+            lose("ELF core alignment bug. Check for proper padding in 'editcore'");
+#ifdef DEBUG_COREPARSE
         printf("Lisp code present in executable @ %lx:%lx (freeptr=%p)\n",
-               (uword_t)&__lisp_code_start, aligned_end, varyobj_free_pointer);
+               (uword_t)&lisp_code_start, (uword_t)&lisp_code_end,
+               varyobj_free_pointer);
 #endif
-        // Prefill the Lisp linkage table so that we can (pending some additional work)
-        // remove "-ldl" from the linker options when making a shrinkwrapped executable.
+        // Prefill the Lisp linkage table so that shrinkwrapped executables which link in
+        // all their C library dependencies can avoid linking with -ldl.
         // All data references are potentially needed because aliencomp doesn't emit
         // SAP-REF-n in a way that admits elision of the linkage entry. e.g.
         //     MOV RAX, [#x20200AA0] ; some_c_symbol
@@ -748,7 +783,7 @@ process_directory(int count, struct ndir_entry *entry,
         // but that's more of a change to the asm instructions than I'm comfortable making;
         // whereas "CALL linkage_entry_for_f" -> "CALL f" is quite straightforward.
         // (Rarely would a jmp indirection be used; maybe for newly compiled code?)
-        lispobj* ptr = &__lisp_linkage_values;
+        lispobj* ptr = &lisp_linkage_values;
         gc_assert(ptr);
         char *link_target = (char*)(intptr_t)LINKAGE_TABLE_SPACE_START;
         int count;
@@ -772,12 +807,17 @@ process_directory(int count, struct ndir_entry *entry,
 #endif
 
     for ( ; --count>= 0; ++entry) {
-        sword_t id = entry->identifier;
+        long id = entry->identifier;
         uword_t addr = entry->address;
+#ifdef DEBUG_COREPARSE
+        printf("space %d @ %10lx pg=%4d+%4d nwords=%ld\n",
+               (int)id, addr, (int)entry->data_page, (int)entry->page_count,
+               entry->nwords);
+#endif
         int compressed = id & DEFLATED_CORE_SPACE_ID_FLAG;
         id -= compressed;
         if (id < 1 || id > MAX_CORE_SPACE_ID)
-            lose("unknown space ID %ld addr %p\n", id, addr);
+            lose("unknown space ID %ld addr %p\n", id, (void*)addr);
 
 #ifndef LISP_FEATURE_RELOCATABLE_HEAP
         int enforce_address = 1;
@@ -831,7 +871,8 @@ process_directory(int count, struct ndir_entry *entry,
                 addr = (uword_t)os_validate(sub_2gb_flag ? MOVABLE_LOW : MOVABLE,
                                             (os_vm_address_t)addr, request);
                 if (!addr) {
-                    lose("Can't allocate %p bytes for space %d", request, id);
+                    lose("Can't allocate %#"OBJ_FMTX" bytes for space %ld",
+                         (lispobj)request, id);
                 }
             }
             switch (id) {
@@ -912,10 +953,6 @@ process_directory(int count, struct ndir_entry *entry,
             set_alloc_pointer((lispobj)free_pointer);
 
             anon_dynamic_space_start = (os_vm_address_t)(addr + len);
-            /* This assertion safeguards the test in zero_pages_with_mmap()
-             * which trusts that if addr > anon_dynamic_space_start
-             * then addr did not come from any file mapping. */
-            gc_assert((lispobj)anon_dynamic_space_start > STATIC_SPACE_END);
         }
     }
 
@@ -928,9 +965,13 @@ process_directory(int count, struct ndir_entry *entry,
     set_adjustment(adj, FIXEDOBJ_SPACE_START, // actual
                    spaces[IMMOBILE_FIXEDOBJ_CORE_SPACE_ID].base, // expected
                    spaces[IMMOBILE_FIXEDOBJ_CORE_SPACE_ID].len);
-    set_adjustment(adj, VARYOBJ_SPACE_START, // actual
-                   spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].base, // expected
-                   spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].len);
+    if (!apply_pie_relocs(VARYOBJ_SPACE_START
+                          - spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].base,
+                          DYNAMIC_SPACE_START - spaces[DYNAMIC_CORE_SPACE_ID].base,
+                          fd))
+        set_adjustment(adj, VARYOBJ_SPACE_START, // actual
+                       spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].base, // expected
+                       spaces[IMMOBILE_VARYOBJ_CORE_SPACE_ID].len);
 #    endif
 #  else
     set_adjustment(adj, DYNAMIC_0_SPACE_START, // actual
@@ -938,7 +979,7 @@ process_directory(int count, struct ndir_entry *entry,
                    spaces[DYNAMIC_CORE_SPACE_ID].len);
 #  endif // LISP_FEATURE_GENCGC
     if (adj->range[0].delta | adj->range[1].delta | adj->range[2].delta) {
-        if (adj->range[1].delta && code_in_elf())
+        if (adj->range[1].delta && lisp_code_in_elf())
             lose("Relocation of fixedobj space not supported with ELF core.\n\
 Please report this as a bug");
         relocate_heap(adj);
@@ -999,14 +1040,13 @@ load_core_file(char *file, os_vm_offset_t file_offset, int merge_core_pages)
 {
     void *header;
     core_entry_elt_t val, *ptr;
-    os_vm_size_t len, remaining_len;
+    os_vm_size_t len, remaining_len, stringlen;
     int fd = open_binary(file, O_RDONLY);
     ssize_t count;
     lispobj initial_function = NIL;
     struct heap_adjust adj;
     memset(&adj, 0, sizeof adj);
 
-    FSHOW((stderr, "/entering load_core_file(%s)\n", file));
     if (fd < 0) {
         fprintf(stderr, "could not open file \"%s\"\n", file);
         perror("open");
@@ -1020,73 +1060,52 @@ load_core_file(char *file, os_vm_offset_t file_offset, int merge_core_pages)
     if (count < (ssize_t) os_vm_page_size) {
         lose("premature end of core file\n");
     }
-    SHOW("successfully read first page of core");
 
     ptr = header;
     val = *ptr++;
 
-    if (val != CORE_MAGIC) {
-        lose("invalid magic number in core: 0x%lx should have been 0x%x.",
-             val,
-             CORE_MAGIC);
-    }
-    SHOW("found CORE_MAGIC");
+    if (val != CORE_MAGIC)
+        lose("invalid magic number in core: %"OBJ_FMTX" should have been %x",
+             (lispobj)val, CORE_MAGIC);
 
-#define WORD_FMTX OS_VM_SIZE_FMTX
     for ( ; ; ptr += remaining_len) {
         val = *ptr++;
         len = *ptr++;
         remaining_len = len - 2; /* (-2 to cancel the two ++ operations) */
-        FSHOW((stderr, "/val=0x%"WORD_FMTX", remaining_len=0x%"WORD_FMTX"\n",
-               val, remaining_len));
-
         switch (val) {
-
-        case END_CORE_ENTRY_TYPE_CODE:
-            free(header);
-            close(fd);
-            return initial_function;
-
         case BUILD_ID_CORE_ENTRY_TYPE_CODE:
-            SHOW("BUILD_ID_CORE_ENTRY_TYPE_CODE case");
-            {
-                os_vm_size_t stringlen = *ptr++;
-                --remaining_len;
-                gc_assert(remaining_len * sizeof (core_entry_elt_t) >= stringlen);
-                if (sizeof build_id == stringlen+1 && !memcmp(ptr, build_id, stringlen))
-                    break;
-                /* .core files are not binary-compatible between
-                 * builds because we can't easily detect whether the
-                 * sources were patched between the time the
-                 * dumping-the-.core runtime was built and the time
-                 * that the loading-the-.core runtime was built.
-                 *
-                 * (We could easily detect whether version.lisp-expr
-                 * was changed, but people experimenting with patches
-                 * don't necessarily update version.lisp-expr.) */
-                fprintf(stderr,
-                        "core was built for runtime \"%.*s\" but this is \"%s\"\n",
-                        (int)stringlen, (char*)ptr, build_id);
-                lose("can't load .core for different runtime, sorry\n");
-            }
-
+            stringlen = *ptr++;
+            --remaining_len;
+            gc_assert(remaining_len * sizeof (core_entry_elt_t) >= stringlen);
+            if (stringlen+1 != sizeof build_id || memcmp(ptr, build_id, stringlen))
+                lose("core was built for runtime \"%.*s\" but this is \"%s\"",
+                     (int)stringlen, (char*)ptr, build_id);
+            break;
         case DIRECTORY_CORE_ENTRY_TYPE_CODE:
             process_directory(remaining_len / NDIR_ENTRY_LENGTH,
                               (struct ndir_entry*)ptr, fd, file_offset,
                               merge_core_pages, &adj);
             break;
-
-        case INITIAL_FUN_CORE_ENTRY_TYPE_CODE:
-            initial_function = adjust_word(&adj, (lispobj)*ptr);
-            break;
-
         case PAGE_TABLE_CORE_ENTRY_TYPE_CODE:
             gc_load_corefile_ptes(ptr[0], ptr[1],
                                   file_offset + (ptr[2] + 1) * os_vm_page_size, fd);
             break;
+        case INITIAL_FUN_CORE_ENTRY_TYPE_CODE:
+            initial_function = adjust_word(&adj, (lispobj)*ptr);
+            break;
+        case END_CORE_ENTRY_TYPE_CODE:
+            free(header);
+            close(fd);
+#ifdef LISP_FEATURE_SB_THREAD
+            if ((int)SymbolValue(FREE_TLS_INDEX,0) >= dynamic_values_bytes) {
+                dynamic_values_bytes = (int)SymbolValue(FREE_TLS_INDEX,0) * 2;
+                // fprintf(stderr, "NOTE: TLS size increased to %x\n", dynamic_values_bytes);
+            }
+#endif
+            return initial_function;
         case RUNTIME_OPTIONS_MAGIC: break; // already processed
         default:
-            lose("unknown core file entry: 0x%"WORD_FMTX"\n", val);
+            lose("unknown core header entry: %"OBJ_FMTX, (lispobj)val);
         }
     }
 }
@@ -1105,10 +1124,9 @@ os_vm_address_t get_asm_routine_by_name(const char* name)
         int i;
         for (i=2 ; i < fixnum_value(table->length) ; i += 2)
             if (lowtag_of(sym = table->data[i]) == OTHER_POINTER_LOWTAG
-                && widetag_of(SYMBOL(sym)->header) == SYMBOL_WIDETAG
+                && widetag_of(&SYMBOL(sym)->header) == SYMBOL_WIDETAG
                 && !strcmp(name, (char*)(VECTOR(SYMBOL(sym)->name)->data)))
-                return code_header_words(code->header)*N_WORD_BYTES
-                    + fixnum_value(CONS(table->data[i+1])->car) + (os_vm_address_t)code;
+                return code_text_start(code) + fixnum_value(CONS(table->data[i+1])->car);
         // Something is wrong if we have a hashtable but find nothing.
         fprintf(stderr, "WARNING: get_asm_routine_by_name(%s) failed\n",
                 name);
