@@ -86,7 +86,9 @@ extern void *return_from_lisp_stub;
 
 /* SIGINT handler that invokes the monitor (for when Lisp isn't up to it) */
 static void
-sigint_handler(int signal, siginfo_t *info, os_context_t *context)
+sigint_handler(int __attribute__((unused)) signal,
+               siginfo_t __attribute__((unused)) *info,
+               os_context_t *context)
 {
     lose("\nSIGINT hit at 0x%08lX\n",
          (unsigned long) *os_context_pc_addr(context));
@@ -179,6 +181,7 @@ Common runtime options:\n\
   --core <filename>          Use the specified core file instead of the default.\n\
   --dynamic-space-size <MiB> Size of reserved dynamic space in megabytes.\n\
   --control-stack-size <MiB> Size of reserved control stack in megabytes.\n\
+  --tls-limit                Maximum number of thread-local symbols.\n\
 \n\
 Common toplevel options:\n\
   --sysinit <filename>       System-wide init-file to use instead of default.\n\
@@ -431,7 +434,7 @@ static void print_environment(int argc, char *argv[])
 extern void write_protect_immobile_space();
 struct lisp_startup_options lisp_startup_options;
 int
-main(int argc, char *argv[], char *envp[])
+sbcl_main(int argc, char *argv[], char *envp[])
 {
 #ifdef LISP_FEATURE_WIN32
     /* Exception handling support structure. Evil Win32 hack. */
@@ -460,8 +463,8 @@ main(int argc, char *argv[], char *envp[])
     int merge_core_pages = -1;
     struct memsize_options memsize_options = {0, 0, 0};
 
+    boolean have_hardwired_spaces = os_preinit(argv, envp);
 #if defined(LISP_FEATURE_WIN32) && defined(LISP_FEATURE_SB_THREAD)
-    os_preinit();
     pthreads_win32_init();
 #endif
 
@@ -497,6 +500,7 @@ main(int argc, char *argv[], char *envp[])
     if (memsize_options.present_in_core) {
         dynamic_space_size = memsize_options.dynamic_space_size;
         thread_control_stack_size = memsize_options.thread_control_stack_size;
+        dynamic_values_bytes = memsize_options.thread_tls_bytes;
         sbcl_argv = argv;
     } else {
         int argi = 1;
@@ -564,6 +568,13 @@ main(int argc, char *argv[], char *envp[])
                     lose("missing argument for --control-stack-size");
                 errno = 0;
                 thread_control_stack_size = parse_size_arg(argv[argi++], "--control-stack-size");
+            } else if (0 == strcmp(arg, "--tls-limit")) {
+                // this is not named "tls-size" because "size" is not the
+                // best measurement for how many symbols to allow
+                ++argi;
+                if (argi >= argc)
+                    lose("missing argument for --tls-limit");
+                dynamic_values_bytes = N_WORD_BYTES * atoi(argv[argi++]);
             } else if (0 == strcmp(arg, "--debug-environment")) {
                 debug_environment_p = 1;
                 ++argi;
@@ -630,14 +641,12 @@ main(int argc, char *argv[], char *envp[])
      * systems (e.g. Alpha) arch_init() needs need os_vm_page_size, so
      * it must follow os_init(). -- WHN 2000-01-26 */
     os_init(argv, envp);
-    /* os_init may re-execute the runtime, don't print anything before
-     * that, otherwise it will be duplicated. */
     if (debug_environment_p) {
         print_environment(argc, argv);
     }
     dyndebug_init();
     arch_init();
-    allocate_spaces();
+    allocate_spaces(have_hardwired_spaces);
     gc_init();
 
     setup_locale();
@@ -727,7 +736,7 @@ main(int argc, char *argv[], char *envp[])
 #endif
 #ifdef LISP_FEATURE_HPUX
     /* -1 = CLOSURE_FUN_OFFSET, 23 = SIMPLE_FUN_CODE_OFFSET, we are
-     * not in LANGUAGE_ASSEMBLY so we cant reach them. */
+     * not in __ASSEMBLER__ so we cant reach them. */
     return_from_lisp_stub = (void *) ((char *)*((unsigned long *)
                  ((char *)initial_function + -1)) + 23);
 #endif
